# GRAVITY

(General-purpose Runtime for Application Virtualization and IT Yield)

To publish on PyPi

```bash
pip install twine
```

```bash
gcc -shared -o add.so add.c
```

```bash
python3 setup.py sdist
```

```bash
twine upload dist/gravity-0.0.1.tar.gz
```
